==> mingw-w64-aws-sdk-cpp-1.10.9-1.src.tar.zst: aws-sdk-cpp-1.10.9/aws-cpp-sdk-macie2/include/aws/macie2/model/ListAllowListsResult.h <==
﻿/**
 * Copyright Amazon.com, Inc. or its affiliates. All Rights Reserved.
 * SPDX-License-Identifier: Apache-2.0.
 */

#pragma once
#include <aws/macie2/Macie2_EXPORTS.h>
#include <aws/core/utils/memory/stl/AWSVector.h>
#include <aws/core/utils/memory/stl/AWSString.h>
#include <aws/macie2/model/AllowListSummary.h>
#include <utility>

namespace Aws
{
template<typename RESULT_TYPE>
class AmazonWebServiceResult;

namespace Utils
{
namespace Json
{
  class JsonValue;
} // namespace Json
} // namespace Utils
namespace Macie2
{
namespace Model
{
  class AWS_MACIE2_API ListAllowListsResult
  {
  public:
    ListAllowListsResult();
    ListAllowListsResult(const Aws::AmazonWebServiceResult<Aws::Utils::Json::JsonValue>& result);
    ListAllowListsResult& operator=(const Aws::AmazonWebServiceResult<Aws::Utils::Json::JsonValue>& result);


    /**
     * <p>An array of objects, one for each allow list.</p>
     */
    inline const Aws::Vector<AllowListSummary>& GetAllowLists() const{ return m_allowLists; }

    /**
     * <p>An array of objects, one for each allow list.</p>
     */
    inline void SetAllowLists(const Aws::Vector<AllowListSummary>& value) { m_allowLists = value; }

    /**
     * <p>An array of objects, one for each allow list.</p>
     */
    inline void SetAllowLists(Aws::Vector<AllowListSummary>&& value) { m_allowLists = std::move(value); }

    /**
     * <p>An array of objects, one for each allow list.</p>
     */
    inline ListAllowListsResult& WithAllowLists(const Aws::Vector<AllowListSummary>& value) { SetAllowLists(value); return *this;}

    /**
     * <p>An array of objects, one for each allow list.</p>
     */
    inline ListAllowListsResult& WithAllowLists(Aws::Vector<AllowListSummary>&& value) { SetAllowLists(std::move(value)); return *this;}

    /**
     * <p>An array of objects, one for each allow list.</p>
     */
    inline ListAllowListsResult& AddAllowLists(const AllowListSummary& value) { m_allowLists.push_back(value); return *this; }

    /**
     * <p>An array of objects, one for each allow list.</p>
     */
    inline ListAllowListsResult& AddAllowLists(AllowListSummary&& value) { m_allowLists.push_back(std::move(value)); return *this; }


    /**
     * <p>The string to use in a subsequent request to get the next page of results in
     * a paginated response. This value is null if there are no additional pages.</p>
     */
    inline const Aws::String& GetNextToken() const{ return m_nextToken; }

    /**
     * <p>The string to use in a subsequent request to get the next page of results in
     * a paginated response. This value is null if there are no additional pages.</p>
     */
    inline void SetNextToken(const Aws::String& value) { m_nextToken = value; }

    /**
     * <p>The string to use in a subsequent request to get the next page of results in
     * a paginated response. This value is null if there are no additional pages.</p>
     */
    inline void SetNextToken(Aws::String&& value) { m_nextToken = std::move(value); }

    /**
     * <p>The string to use in a subsequent request to get the next page of results in
     * a paginated response. This value is null if there are no additional pages.</p>
     */
    inline void SetNextToken(const char* value) { m_nextToken.assign(value); }

    /**
     * <p>The string to use in a subsequent request to get the next page of results in
     * a paginated response. This value is null if there are no additional pages.</p>
     */
    inline ListAllowListsResult& WithNextToken(const Aws::String& value) { SetNextToken(value); return *this;}

    /**
     * <p>The string to use in a subsequent request to get the next page of results in
     * a paginated response. This value is null if there are no additional pages.</p>
     */
    inline ListAllowListsResult& WithNextToken(Aws::String&& value) { SetNextToken(std::move(value)); return *this;}

    /**
     * <p>The string to use in a subsequent request to get the next page of results in
     * a paginated response. This value is null if there are no additional pages.</p>
     */
    inline ListAllowListsResult& WithNextToken(const char* value) { SetNextToken(value); return *this;}

  private:

    Aws::Vector<AllowListSummary> m_allowLists;

    Aws::String m_nextToken;
  };

} // namespace Model
} // namespace Macie2
} // namespace Aws

==> mingw-w64-aws-sdk-cpp-1.10.55-1.src.tar.zst: aws-sdk-cpp-1.10.55/aws-cpp-sdk-macie2/include/aws/macie2/model/ListAllowListsResult.h <==
﻿/**
 * Copyright Amazon.com, Inc. or its affiliates. All Rights Reserved.
 * SPDX-License-Identifier: Apache-2.0.
 */

#pragma once
#include <aws/macie2/Macie2_EXPORTS.h>
#include <aws/core/utils/memory/stl/AWSVector.h>
#include <aws/core/utils/memory/stl/AWSString.h>
#include <aws/macie2/model/AllowListSummary.h>
#include <utility>

namespace Aws
{
template<typename RESULT_TYPE>
class AmazonWebServiceResult;

namespace Utils
{
namespace Json
{
  class JsonValue;
} // namespace Json
} // namespace Utils
namespace Macie2
{
namespace Model
{
  class ListAllowListsResult
  {
  public:
    AWS_MACIE2_API ListAllowListsResult();
    AWS_MACIE2_API ListAllowListsResult(const Aws::AmazonWebServiceResult<Aws::Utils::Json::JsonValue>& result);
    AWS_MACIE2_API ListAllowListsResult& operator=(const Aws::AmazonWebServiceResult<Aws::Utils::Json::JsonValue>& result);


    /**
     * <p>An array of objects, one for each allow list.</p>
     */
    inline const Aws::Vector<AllowListSummary>& GetAllowLists() const{ return m_allowLists; }

    /**
     * <p>An array of objects, one for each allow list.</p>
     */
    inline void SetAllowLists(const Aws::Vector<AllowListSummary>& value) { m_allowLists = value; }

    /**
     * <p>An array of objects, one for each allow list.</p>
     */
    inline void SetAllowLists(Aws::Vector<AllowListSummary>&& value) { m_allowLists = std::move(value); }

    /**
     * <p>An array of objects, one for each allow list.</p>
     */
    inline ListAllowListsResult& WithAllowLists(const Aws::Vector<AllowListSummary>& value) { SetAllowLists(value); return *this;}

    /**
     * <p>An array of objects, one for each allow list.</p>
     */
    inline ListAllowListsResult& WithAllowLists(Aws::Vector<AllowListSummary>&& value) { SetAllowLists(std::move(value)); return *this;}

    /**
     * <p>An array of objects, one for each allow list.</p>
     */
    inline ListAllowListsResult& AddAllowLists(const AllowListSummary& value) { m_allowLists.push_back(value); return *this; }

    /**
     * <p>An array of objects, one for each allow list.</p>
     */
    inline ListAllowListsResult& AddAllowLists(AllowListSummary&& value) { m_allowLists.push_back(std::move(value)); return *this; }


    /**
     * <p>The string to use in a subsequent request to get the next page of results in
     * a paginated response. This value is null if there are no additional pages.</p>
     */
    inline const Aws::String& GetNextToken() const{ return m_nextToken; }

    /**
     * <p>The string to use in a subsequent request to get the next page of results in
     * a paginated response. This value is null if there are no additional pages.</p>
     */
    inline void SetNextToken(const Aws::String& value) { m_nextToken = value; }

    /**
     * <p>The string to use in a subsequent request to get the next page of results in
     * a paginated response. This value is null if there are no additional pages.</p>
     */
    inline void SetNextToken(Aws::String&& value) { m_nextToken = std::move(value); }

    /**
     * <p>The string to use in a subsequent request to get the next page of results in
     * a paginated response. This value is null if there are no additional pages.</p>
     */
    inline void SetNextToken(const char* value) { m_nextToken.assign(value); }

    /**
     * <p>The string to use in a subsequent request to get the next page of results in
     * a paginated response. This value is null if there are no additional pages.</p>
     */
    inline ListAllowListsResult& WithNextToken(const Aws::String& value) { SetNextToken(value); return *this;}

    /**
     * <p>The string to use in a subsequent request to get the next page of results in
     * a paginated response. This value is null if there are no additional pages.</p>
     */
    inline ListAllowListsResult& WithNextToken(Aws::String&& value) { SetNextToken(std::move(value)); return *this;}

    /**
     * <p>The string to use in a subsequent request to get the next page of results in
     * a paginated response. This value is null if there are no additional pages.</p>
     */
    inline ListAllowListsResult& WithNextToken(const char* value) { SetNextToken(value); return *this;}

  private:

    Aws::Vector<AllowListSummary> m_allowLists;

    Aws::String m_nextToken;
  };

} // namespace Model
} // namespace Macie2
} // namespace Aws
